/////////////////////////////////////////////////////////////////////////////
///
/// @file
///
/// Configuration for the Chialvo neuron model in R^2
/// with 2 varying parameters.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2022 by Pawel Pilarczyk.
//
// This file is part of my research software package. This is free software:
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this software; see the file "license.txt". If not,
// please, see <https://www.gnu.org/licenses/>.

// Started on February 9, 2008. Last revision: July 18, 2022.


#ifndef _CMGRAPHS_CONFIG_H_
#define _CMGRAPHS_CONFIG_H_


// Use single parameter points instead of parameter intervals.
// Comment this setting out for the final computations.
//#define CONFIG_PARAMPOINTS

// Do preprocessing only and skip the matching part.
//#define CONFIG_ONLYPREPROCESSING


// --------------------------------------------------
// -------------- THE PARAMETER RANGES --------------
// --------- AND THE PHASE SPACE SELECTION ----------
// --------------------------------------------------

#include "p_neuron12.h"
using namespace custom::neuron12;


// --------------------------------------------------
// --------------- THE MAP SELECTION ----------------
// --------------------------------------------------

#include "m_neuron1.h"

/// Defines the type of the map to be used for the computations.
/// The corresponding header file must be included prior to this definition.
typedef MapNeuron1 theMapType;


// --------------------------------------------------
// -------------- KNOWN CONLEY INDICES --------------
// --------------------------------------------------

#include "indknown.h"
using namespace custom::noKnownIndices;


// --------------------------------------------------
// ---- POST-PROCESSING OF MORSE DECOMPOSITIONS -----
// --------------------------------------------------

#include "procmdec.h"
//#include "procrecur.h"
using namespace custom::noProcMorseDec;
//using namespace custom::procRecurrence;


// --------------------------------------------------
// ------------- COMPATIBILITY CONTROL --------------
// --------------------------------------------------

/// The control number that is used to confirm the compatibility
/// between the coordinator and workers.
/// Please, increase this number by 1 every time the configuration
/// of the program changes substantially (e.g., different parameter ranges,
/// different numbers of subintervals, or different maps are chosen).
const int controlNumber = 20112;


#endif // _CMGRAPHS_CONFIG_H_

