#!/usr/bin/perl

#############################################################################
#
# This Perl script determines the maximal memory usage,
# based on the log files created by the script "memguard.pl".
# This script was initially based on "maxavgsize.pl".
#
#############################################################################

# Copyright (C) 1997-2014 by Pawel Pilarczyk.
#
# This file is part of my research software package. This is free software:
# you can redistribute it and/or modify it under the terms of the GNU
# General Public License as published by the Free Software Foundation,
# either version 3 of the License, or (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this software; see the file "license.txt". If not,
# please, see <https://www.gnu.org/licenses/>.

# Started on December 17, 2010. Last revision: August 18, 2011.


my @files = scalar (@ARGV) ? @ARGV : ('*.mem');

my $maxmem = 0;
my $maxfile;
my $maxline;
foreach my $pattern (@files)
{
	foreach my $filename (glob $pattern)
	{
		next unless -f $filename;
		open ($file, $filename) or next;
		my $initial = 1;
		my %ignored;
		my $line = 0;
		while (<$file>)
		{
			#increase line counter
			++ $line;

			# detect the end of the initial stage
			if (m/^Watching/)
			{
				$initial = 0;
				next;
			}

			# ignore lines not showing memory usage
			next unless m/^Process (\d+): (\d+) MB/;

			# determine the process number
			my $proc = $1;

			# skip it if it is in the "ignored" list
			next if defined $ignored{$proc};

			# determine the memory amount being used
			my $mem = $2;

			# update the list of ignored processes if necessary
			if ($initial && ($mem > 500))
			{
				$ignored{$proc} = $mem;
			#	print "Note: Ignoring process $proc " .
			#		"in '$filename'.\n";
				next;
			}

			# update the max memory used so far
			next if ($mem < $maxmem);
			$maxmem = $mem;
			$maxfile = $filename;
			$maxline = $line;
		}
		close $file;
	}
}

print "Max mem: $maxmem MB ($maxfile, line $maxline).\n";

